### CHANGE LOG
---

#### 1.0.01 (29/01/2024)
- First Release

#### 1.0.02 (02/02/2024)
- First Revision, Including:
    - Axes in the plot is now available
    - Windrose plot is now available (not include subplots)
    - demo4, demo9 released
    - README.md updated